import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ContractRolesService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get wallets for role
     * Get all wallets with a specific role for a contract.
     * @param role The role to list wallet members
     * @param chain Chain ID or name
     * @param contractAddress Contract address
     * @returns any Default Response
     * @throws ApiError
     */
    getRole(role: string, chain: string, contractAddress: string): CancelablePromise<{
        result: Array<string>;
    }>;
    /**
     * Get wallets for all roles
     * Get all wallets in each role for a contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract address
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            admin: Array<string>;
            transfer: Array<string>;
            minter: Array<string>;
            pauser: Array<string>;
            lister: Array<string>;
            asset: Array<string>;
            unwrap: Array<string>;
            factory: Array<string>;
            signer: Array<string>;
        };
    }>;
    /**
     * Grant role
     * Grant a role to a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress Contract address
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @param xAccountAddress Smart account address
     * @param xAccountFactoryAddress Smart account factory address. If omitted, engine will try to resolve it from the chain.
     * @param xAccountSalt Smart account salt as string or hex. This is used to predict the smart account address. Useful when creating multiple accounts with the same admin and only needed when deploying the account as part of a userop.
     * @returns any Default Response
     * @throws ApiError
     */
    grant(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The role to grant
         */
        role: string;
        /**
         * The address to grant the role to
         */
        address: string;
        txOverrides?: {
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
            /**
             * Maximum duration that a transaction is valid. If a transaction cannot be sent before the timeout, the transaction will be set to 'errored'. Default: no timeout
             */
            timeoutSeconds?: number;
            /**
             * Amount of native currency in wei to send with this transaction. Used to transfer funds or pay a contract.
             */
            value?: string;
        };
    }, simulateTx?: boolean, xIdempotencyKey?: string, xAccountAddress?: string, xAccountFactoryAddress?: string, xAccountSalt?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Revoke role
     * Revoke a role from a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress Contract address
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @param xAccountAddress Smart account address
     * @param xAccountFactoryAddress Smart account factory address. If omitted, engine will try to resolve it from the chain.
     * @param xAccountSalt Smart account salt as string or hex. This is used to predict the smart account address. Useful when creating multiple accounts with the same admin and only needed when deploying the account as part of a userop.
     * @returns any Default Response
     * @throws ApiError
     */
    revoke(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The role to revoke
         */
        role: string;
        /**
         * The address to revoke the role from
         */
        address: string;
        txOverrides?: {
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
            /**
             * Maximum duration that a transaction is valid. If a transaction cannot be sent before the timeout, the transaction will be set to 'errored'. Default: no timeout
             */
            timeoutSeconds?: number;
            /**
             * Amount of native currency in wei to send with this transaction. Used to transfer funds or pay a contract.
             */
            value?: string;
        };
    }, simulateTx?: boolean, xIdempotencyKey?: string, xAccountAddress?: string, xAccountFactoryAddress?: string, xAccountSalt?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
